@@ -12,8 +12,9 @@ class Worker(object):
     jobs = None
     executor = None
     results = None
+    config = BatchScript.config
 
-    def __init__(self, func, jobs: ThreadQueue, results: ProcessQueue, config=BatchScript.config):
+    def __init__(self, func, jobs: ThreadQueue, results: ProcessQueue, config=None):
         self.func = func
         self.jobs = jobs
         self.results = results
@@ -33,12 +34,20 @@ class Worker(object):
             batch_submit = time.time()
             for item in items:
                 works.append(self.executor.submit(self.func, item))
+            work_results = []
             for work in as_completed(works):
-                self.results.put(work.result())
+                if self.config.ResultsBatchSize == 0:
+                    self.results.put(work.result())
+                else:
+                    if len(work_results) < self.config.ResultsBatchSize:
+                        work_results.append(work.result())
+                    else:
+                        self.results.put(work_results)
+                        work_results = []
             batch_completed = time.time()
             if items:
                 job_count = len(items)
                 timedelta = batch_completed - batch_submit
                 speed = job_count / timedelta
-                print("Batch completed in {} seconds with {} jobs speed {}/s".format(timedelta, job_count, speed))
+                print("{} batch completed in {} seconds with {} jobs speed {}/s".format(self.func.__name__, timedelta, job_count, speed))
 
